@@ -6,7 +6,7 @@ use strict;
 use POSIX qw(strftime);
 use Time::Local;
 
-our $VERSION = '0.06';
+our $VERSION = '0.10';
 
 my $LAX_DATE_RE  = qr<[0-9]{4}[-/](?:0[1-9]|1[0-2])[-/](?:0[1-9]|[12][0-9]|3[01])>;
 my $TIME_RE      = qr<(?:[01][0-9]|2[0-3]):[0-5][0-9]:[0-6][0-9]>;
@@ -58,6 +58,7 @@ sub today_stamp
 sub day_end
 {
     my ( $stamp ) = @_;
+    return unless defined $stamp;
     return App::TimelogTxt::Utils::fmt_date( stamp_to_localtime( $stamp ) + $ONE_DAY );
 }
 
@@ -142,7 +143,7 @@ App::TimelogTxt::Utils - Utility functions for the App::TimelogTxt modules.
 
 =head1 VERSION
 
-This document describes App::TimelogTxt::Utils version 0.06
+This document describes App::TimelogTxt::Utils version 0.10
 
 =head1 SYNOPSIS
 
@@ -200,6 +201,10 @@ The supplied datestamp is returned.
 
 =back
 
+=head2 prev_stamp( $stamp )
+
+Return a date stamp for the day before the date represented by C<$stamp>.
+
 =head2 fmt_date( $time )
 
 Return a properly formatted datestamp for the day corresponding to C<$time>
